@@ -361,6 +361,7 @@ canonical <- function(term=quote(`%in%`(table=Table, x=X)), drop=TRUE)
 #' Hook for custom symbols
 #' 
 #' hook(term, display)
+#' hook_fn(fn)
 #' unhook(term)
 #' hooked(term)
 #'
@@ -376,6 +377,9 @@ canonical <- function(term=quote(`%in%`(table=Table, x=X)), drop=TRUE)
 #' @param as.rolog (default is TRUE)
 #' indicates that simplified quasi-quotation is to be used.
 #'
+#' @param fn
+#' a custom function. The name of _fn_ is replaced by its function body.
+#' 
 #' @return
 #' hook and unhook return TRUE on success. hooked returns the hooked
 #' expression or FALSE on failure.
@@ -390,15 +394,16 @@ canonical <- function(term=quote(`%in%`(table=Table, x=X)), drop=TRUE)
 #' mathml(quote(t0))
 #' unhook(t0)
 #' mathml(quote(t0))
+#' square <- function(x) {x^2} ; hook_fn(square)
 #'
-hook <- function(term, display, quote=TRUE, as.rolog=TRUE)
+hook <- function(term, display=NULL, quote=TRUE, as.rolog=TRUE)
 {
   if(quote)
   {
     term <- substitute(term)
     display <- substitute(display)
   }
-
+  
   if(as.rolog)
   {
     term <- rolog::as.rolog(term)
@@ -440,6 +445,20 @@ hooked <- function(term)
   return(r$X)
 }
 
+#' @rdname hook
+#' @export
+hook_fn <- function(fn)
+{
+  name <- as.character(substitute(fn))
+  args <- names(formals(fn))
+  dotargs <- sprintf(".%s", args)
+  subst <- lapply(dotargs, as.name)
+  arg1 <- as.call(c(as.name(name), subst))
+  names(subst) <- args
+  arg2 <- do.call(substitute, list(body(fn), subst))
+  eval(call("hook", arg1, arg2))
+}
+
 #' Multiplication
 #'
 #' @name dot
